==> confidence-test-0.1.0-sources.jar: org/saynotobugs/confidence/test.quality/Passed.java <==
/*
 * Copyright 2022 dmfs GmbH
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.saynotobugs.confidence.test.quality;

import org.dmfs.srcless.annotations.staticfactory.StaticFactories;
import org.saynotobugs.confidence.Assessment;
import org.saynotobugs.confidence.assessment.Fail;
import org.saynotobugs.confidence.assessment.FailPrepended;
import org.saynotobugs.confidence.description.Delimited;
import org.saynotobugs.confidence.description.TextDescription;
import org.saynotobugs.confidence.quality.composite.QualityComposition;


@StaticFactories("Test")
public final class Passed extends QualityComposition<Assessment>
{

    public Passed()
    {
        super(actual -> actual.isSuccess()
                ? new FailPrepended(new TextDescription("passed but described failure"), new DescribesAs("").assessmentOf(actual.description()))
                : new Fail(new Delimited("failed with", actual.description())),
            new TextDescription("passed"));
    }
}

==> confidence-test-0.50.0-sources.jar: org/saynotobugs/confidence/test.quality/Passed.java <==
/*
 * Copyright 2022 dmfs GmbH
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.saynotobugs.confidence.test.quality;

import org.dmfs.srcless.annotations.staticfactory.DeprecatedFactories;
import org.dmfs.srcless.annotations.staticfactory.StaticFactories;
import org.saynotobugs.confidence.Assessment;
import org.saynotobugs.confidence.assessment.Fail;
import org.saynotobugs.confidence.assessment.FailPrepended;
import org.saynotobugs.confidence.description.Delimited;
import org.saynotobugs.confidence.description.Text;
import org.saynotobugs.confidence.quality.composite.QualityComposition;


@StaticFactories(
    value = "Assessment",
    deprecates = @DeprecatedFactories(value = "Test"))
public final class Passed extends QualityComposition<Assessment>
{

    public Passed()
    {
        super(actual -> actual.isSuccess()
                ? new FailPrepended(new Text("passed but described failure"), new DescribesAs("").assessmentOf(actual.description()))
                : new Fail(new Delimited("failed with", actual.description())),
            new Text("passed"));
    }
}
